==> contentsquare-2.0.0.tar.gz: test/src/modules/screengraph/decompress_tvp_test.dart <==
import 'package:contentsquare/src/modules/screengraph/hit_test/get_tvp_at_hit_position.dart';
import 'package:contentsquare/src/modules/screengraph/painted_render_object_tree.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

import '../../../helpers/decompress_tvp.dart';
import '../../../helpers/matchers/fixtures/matcher.dart';
import '../../../helpers/get_center.dart';

void main() {
  testWidgets(
    'Should return the expected decompressed TVP',
    (WidgetTester tester) async {
      const _key = ValueKey('Text');
      await tester.pumpWidget(
        const MaterialApp(
          home: Scaffold(
            body: Center(
              child: SizedBox(
                width: 100,
                height: 100,
                child: Text('Text', key: _key),
              ),
            ),
          ),
        ),
      );

      final hitTVPs = getTVPAtHitPosition(
        getCenterFromRenderBoxKey(key: _key),
      );
      final decompressedHitTVPs =
          hitTVPs.map((hitTVP) => decompressTVP(tvp: hitTVP)).toList();

      expect(
        decompressedHitTVPs.single,
        matchesFixture('decompressedHitTVPFixture'),
      );
    },
  );

  testWidgets(
    'Should return the expected decompressed screengraph',
    (tester) async {
      const _key = ValueKey('Text');
      await tester.pumpWidget(
        const MaterialApp(
          home: Scaffold(
            body: Center(
              child: SizedBox(
                width: 100,
                height: 100,
                child: Text('Text', key: _key),
              ),
            ),
          ),
        ),
      );

      // Don't use the [nativePath] from the fixture so that
      // [decompressScreengraph] would fail if it imported the fixture instead
      // of using the given argument
      const testNativePath = 'SomeNativePath';

      final screengraph = await getScreengraphFromRoot(
        nativePath: testNativePath,
        pixelRatio: 1,
      );
      final decompressedScreengraph = decompressScreengraph(
        nativePath: testNativePath,
        screengraphString: screengraph,
      );

      expect(
        decompressedScreengraph,
        matchesFixture('decompressedScreengraphFixture'),
      );
    },
  );
}

==> contentsquare-2.3.0.tar.gz: test/src/modules/screengraph/decompress_tvp_test.dart <==
import 'package:contentsquare/src/modules/screengraph/hit_test/get_tvp_at_hit_position.dart';
import 'package:contentsquare/src/modules/screengraph/painted_render_object_tree.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';

import '../../../helpers/decompress_tvp.dart';
import '../../../helpers/matchers/fixtures/matcher.dart';
import '../../../helpers/get_center.dart';

void main() {
  testWidgets(
    'Should return the expected decompressed TVP',
    (WidgetTester tester) async {
      const key = ValueKey('Text');
      await tester.pumpWidget(
        const MaterialApp(
          home: Scaffold(
            body: Center(
              child: SizedBox(
                width: 100,
                height: 100,
                child: Text('Text', key: key),
              ),
            ),
          ),
        ),
      );

      final hitTVPs = getTVPAtHitPosition(
        getCenterFromRenderBoxKey(key: key),
      );
      final decompressedHitTVPs =
          hitTVPs.map((hitTVP) => decompressTVP(tvp: hitTVP)).toList();

      expect(
        decompressedHitTVPs.single,
        matchesFixture('decompressedHitTVPFixture'),
      );
    },
  );

  testWidgets(
    'Should return the expected decompressed screengraph',
    (tester) async {
      const key = ValueKey('Text');
      await tester.pumpWidget(
        const MaterialApp(
          home: Scaffold(
            body: Center(
              child: SizedBox(
                width: 100,
                height: 100,
                child: Text('Text', key: key),
              ),
            ),
          ),
        ),
      );

      // Don't use the [nativePath] from the fixture so that
      // [decompressScreengraph] would fail if it imported the fixture instead
      // of using the given argument
      const testNativePath = 'SomeNativePath';

      final screengraph = await getScreengraphFromRoot(
        nativePath: testNativePath,
        pixelRatio: 1,
      );
      final decompressedScreengraph = decompressScreengraph(
        nativePath: testNativePath,
        screengraphString: screengraph,
      );

      expect(
        decompressedScreengraph,
        matchesFixture('decompressedScreengraphFixture'),
      );
    },
  );
}
